<?php

namespace IQBall\App\Controller;

use IQBall\App\Session\SessionHandle;
use IQBall\App\ViewHttpResponse;
use IQBall\Core\Model\TacticModel;
use IQBall\Core\Model\TeamModel;
use IQBall\Core\Http\HttpResponse;

class TacticController {
    private TacticModel $tactics;
    private ?TeamModel $teams;

    public function __construct(TacticModel $tactics, ?TeamModel $teams = null) {
        $this->tactics = $tactics;
        $this->teams = $teams;
    }

    /**
     * @param bool $toShare
     * @param SessionHandle $session
     * @return ViewHttpResponse
     */
    public function displayTactic(bool $toShare, SessionHandle $session): ViewHttpResponse {
        if($toShare) {
            $results = $this->tactics->getAll($session->getAccount()->getUser()->getId());
        } else {
            $results = $this->tactics->getAllTacticSharedOwned($session->getAccount()->getUser()->getId());
        }

        return ViewHttpResponse::twig("display_tactic.html.twig", ['tactics' => $results, 'toShare' => $toShare]);
    }

    /**
     * @param bool $toShare
     * @param int $tacticId
     * @param SessionHandle $session
     * @return ViewHttpResponse
     */
    public function displayTeamAndAccount(bool $toShare, int $tacticId, SessionHandle $session): ViewHttpResponse {
        if($toShare) {
            $results = $this->teams->getAllIsCoach($session->getAccount()->getUser()->getId());
        } else {
            $results = $this->teams->getAllIsCoach($session->getAccount()->getUser()->getId());
        }
        return ViewHttpResponse::twig("display_user_teams_accounts.html.twig", ['teams' => $results, 'tactic' => $tacticId, 'toShare' => $toShare]);
    }

    /**
     * @param int $tacticId
     * @param int $teamId
     * @param SessionHandle $session
     * @return ViewHttpResponse
     */
    public function displayShareConfirmation(int $tacticId, int $teamId, SessionHandle $session): ViewHttpResponse {
        return ViewHttpResponse::twig("display_share_confirmation.html.twig", ['team' => $teamId, 'tactic' => $tacticId]);
    }

    /**
     * @param array<array<string, mixed>> $confirmation
     * @param int $tacticId
     * @param int $teamId
     * @param SessionHandle $session
     * @return HttpResponse
     */
    public function shareTacticToTeam(array $confirmation, int $tacticId, int $teamId, SessionHandle $session): HttpResponse {
        if($confirmation['confirmation'] == "yes") {
            $this->teams->shareTacticToTeam($teamId, $tacticId);
        }
        return ViewHttpResponse::redirect("/");
    }

    /**
     * @param array<string> $request
     * @param int $tacticId
     * @param SessionHandle $session
     * @return HttpResponse
     */
    public function shareTacticToAccount(array $request, int $tacticId, SessionHandle $session): HttpResponse {
        $email = $request["email"];
        $this->tactics->shareTacticToAccountMail($email, $tacticId);
        return ViewHttpResponse::redirect("/");
    }

    /**
     * @param int $tacticId
     * @param SessionHandle $session
     * @return HttpResponse
     */
    public function unshareTactic(int $tacticId, SessionHandle $session): HttpResponse {
        $this->tactics->unshareTactic($tacticId);
        $this->teams->unshareTactic($tacticId);
        return ViewHttpResponse::redirect("/");
    }

    /**
     * @param int $tacticId
     * @param int $teamId
     * @param SessionHandle $session
     * @return HttpResponse
     */
    public function unshareTacticToTeam(int $tacticId, int $teamId, SessionHandle $session): HttpResponse {
        $this->teams->unshareTacticToTeam($tacticId, $teamId);
        return ViewHttpResponse::redirect("/");
    }

    /**
     * @param int $tacticId
     * @param int $accountId
     * @param SessionHandle $session
     * @return HttpResponse
     */
    public function unshareTacticToAccount(int $tacticId, int $accountId, SessionHandle $session): HttpResponse {
        $this->tactics->unshareTacticToAccount($tacticId, $accountId);
        return ViewHttpResponse::redirect("/");
    }

}
